
$(function () {

    var plot, samples;

    var location = window.location;
    var trndloc = location.origin + location.pathname;

    $("#header-title a").attr('href',trndloc);

    var options = {
        series: {
            shadowSize: 0	// Drawing is faster without shadows
        },
        grid: {
            hoverable: true,
            clickable: false
        },
        /*yaxis: {
         min: -1,
         max: 1
         },*/
        xaxis: {
            mode: "time",
            timezone: "browser",
            show: true
        },
        zoom: {
            interactive: true
        },
        pan: {
            interactive: false,
        },
    }


    $.ajax({
        url: trndloc + ":Title",
        headers: {Accept: "application/json"},
    }).done(function (data) {
        var title = "Trend title";
        $("#header-title h1").text(title);
        document.title = title;
    })

    var refresh = function () {
        $.ajax({
            url: trndloc + "?jsondata",
        }).done(function (data) {

            var l = data.length;
            var n = l > 0 ? data[0].length - 1 : 0;
            samples = new Array(n);

            for (j = 0; j < n; j++) {
                var y = new Array(l);
                var s = j + 1;

                for (i = 0; i < data.length; i++) {
                    var item = [data[i][0] + 946684800000, data[i][s]];
                    y[i] = item;
                }
                samples[j] = {data: y, label: "signal " + s.toString()}
            }

            plot = $.plot("#placeholder", samples,
                    $.extend(true, {}, options, {
                        selection: {mode: "xy"},
                    })
            );
        });
    }

    refresh();

    $("<div id='tooltip'></div>").css({
        position: "absolute",
        display: "none",
        border: "1px solid #fdd",
        padding: "2px",
        "background-color": "#fee",
        opacity: 0.80
    }).appendTo("body");

    $("#placeholder").bind("plothover", function (event, pos, item) {
        if (item) {
            var x = item.datapoint[0],
                    y = item.datapoint[1].toString();

            $("#tooltip").html(item.series.label + "<br>" + new Date(x).toLocaleString() + "<br> value: " + y)
                    .css({top: item.pageY + 5, left: item.pageX + 5})
                    .fadeIn(200);
        } else {
            $("#tooltip").hide();
        }
    });

    $("#placeholder").bind("plotselected", function (event, ranges) {
        if (ranges.xaxis.to - ranges.xaxis.from < 0.00001) {
            ranges.xaxis.to = ranges.xaxis.from + 0.00001;
        }

        if (ranges.yaxis.to - ranges.yaxis.from < 0.00001) {
            ranges.yaxis.to = ranges.yaxis.from + 0.00001;
        }

        plot = $.plot("#placeholder", samples,
                $.extend(true, {}, options, {
                    xaxis: {min: ranges.xaxis.from, max: ranges.xaxis.to},
                    yaxis: {min: ranges.yaxis.from, max: ranges.yaxis.to},
                    selection: {mode: "xy"},
                })
        );
    });


    var panning = function (e) {
        var axes = plot.getAxes();
        plot = $.plot("#placeholder", samples,
                $.extend(true, {}, options, {
                    pan: {interactive: e.ctrlKey},
                    selection: e.ctrlKey ? {} : {mode: "xy"},
                    xaxis: {min: axes.xaxis.min, max: axes.xaxis.max},
                    yaxis: {min: axes.yaxis.min, max: axes.yaxis.max}
                })
        );
    }

    $(this).keydown(function (e) {
        if ((e.which == 32) || (e.which == 13)) {
            refresh();
        } else {
            panning(e);
        }
    });

    $(this).keyup(function (e) {
        panning(e);
    });


});